Posterior Samples to FITS Files (`ligo-skymap-from-samples`)
============================================================

.. argparse::
    :module: ligo.skymap.tool.ligo_skymap_from_samples
    :func: parser
